/** @example ex/ios/ExampleInterface.h
 */

/*
 *  Copyright 2014-2025 Solace Corporation. All rights reserved.
 */

#import "Example.h"

@class Example;

/**
 *  The ExampleInterface class initializes each example object and allows the UI
 *  to access and manipulate them.
 */
@interface ExampleInterface : NSObject

/**
 *  Contains each example object used by the application.
 */
@property NSMutableArray *examples;

/**
 *  The currently running example.
 */
@property Example *runningExample;

/**
 *  Gets the example at the specified index in the examples array.
 *
 *  @param index The index in the examples array.
 *
 *  @return The example at the specified index.
 */
- (Example *)example:(int)index;

/**
 *  Gets the name of the example at the specified index in the examples array.
 *
 *  @param index The index in the examples array.
 *
 *  @return The name of the example at the specified index.
 */
- (NSString *)exampleName:(int)index;

/**
 *  Gets the description of the example at the specified index in the examples
 *  array.
 *
 *  @param index The index in the examples array.
 *
 *  @return The description of the example at the specified index.
 */
- (NSString *)exampleDescription:(int)index;

/**
 *  Gets the number of examples in the examples array.
 *
 *  @return The number of examples in the examples array.
 */
- (int)numberOfExamples;

@end
