/** @example ex/ios/LogCallbackProtocol.h
 */

/*
 *  Copyright 2014-2025 Solace Corporation. All rights reserved.
 */

#import <Foundation/Foundation.h>
#import "solclient/solClient.h"

/**
 *  The LogCallbackProtocol protocol defines the methods used for the logging
 *  callback by the examples in the application. The method has a C function
 *  counterpart, as the CCSMP API does not support passing Objective C
 *  methods as function pointers.
 *
 *  This protocol is used in the same manner as the EventCallbackProtocol.
 *  Please see the documentation for that protocol for more information.
 */
@protocol LogCallbackProtocol <NSObject>

/**
 *  Callback for log events. The callback is registered with the logger and is
 *  called whenever a log event occurs.
 *
 *  @param logInfo_p A pointer to information about the log event, such as the
 *                   category and message.
 *  @param userData  A pointer to opaque user data.
 */
- (void)logCallbackWithLogInfo:(solClient_log_callbackInfo_pt)logInfo_p
                      userData:(void *)user_p;

/**
 *  The corresponding C function for logCallbackWithLogInfo:userData. See the
 *  documentation for that method for more information.
 *
 *  @param logInfo_p A pointer to information about the log event, such as the
 *                   category and message.
 *  @param userData  A pointer to an instance of the callbackBridge_t
 *                   struct.
 */
void logCallback(solClient_log_callbackInfo_pt logInfo_p, void *user_p);

@end
