/** @example  ex/ios/Parameter.h
 */

/*
 *  Copyright 2014-2025 Solace Corporation. All rights reserved.
 */

/**
 *  The Parameter class represents a configuration option for an example, such
 *  as a hostname or VPN.
 */
@interface Parameter : NSObject <UIPickerViewDelegate, UIPickerViewDataSource>

/**
 *  Default command line parameter IDs used in most examples.
 */
#define PARAMETER_USERNAME @"username"
#define PARAMETER_PASSWORD @"password"
#define PARAMETER_VPN @"vpn"
#define PARAMETER_HOST @"host"
#define PARAMETER_CACHE_NAME @"cacheName"
#define PARAMETER_DESTINATION_TOPIC @"destinationTopic"
#define PARAMETER_NUM_MESSAGES @"numOfMsgs"
#define PARAMETER_MESSAGES_RATE @"msgRate"
#define PARAMETER_LOGGING_LEVEL @"loggingLevel"
#define PARAMETER_COMPRESSION @"compression"

/**
 *  Other command line parameter IDs used in a limited number of examples.
 */
#define PARAMETER_SEMP_VERSION @"sempVersion"
#define PARAMETER_MESSAGE_SIZE @"messageSize"
#define PARAMETER_PUB_SUB_MODE @"pubSubMode"
#define PARAMETER_PUB_SUB_QUANTITY @"pubSubQuantity"
#define PARAMETER_TCP_NO_DELAY @"tcpNoDelay"
#define PARAMETER_MULTI_SEND_MODE @"multiSendMode"
#define PARAMETER_SSL_TRUST_STORE_DIRECTORY @"sslTrustStore"
#define PARAMETER_SSL_COMMON_NAMES @"sslCommonNames"
#define PARAMETER_SSL_NO_PROTOCOLS @"sslNoProtocols"
#define PARAMETER_SSL_CIPHER_LIST @"sslCiphers"
#define PARAMETER_SSL_CERTIFICATE_VALIDATION @"sslCertificateValidation"
#define PARAMETER_SSL_CERTIFICATE_DATE_VALIDATION                              \
    @"sslCertificateDateValidation"
#define PARAMETER_SSL_AUTHENTICATION_SCHEME @"sslAuthenticationScheme"
#define PARAMETER_SSL_CERTIFICATE @"sslCertificate"
#define PARAMETER_SSL_PRIVATE_KEY @"sslPrivateKey"
#define PARAMETER_SSL_PRIVATE_KEY_PASSWORD @"sslPrivateKeyPassword"
#define PARAMETER_SSL_CONNECTION_DOWNGRADE_TO @"sslConnectionDowngradeTo"
#define PARAMETER_WEB_PROTOCOL @"webProtocol"

/**
 *  Represents the possible parameter data types.
 *  - A StringParameter has a string value, and corresponds to the text box UI
 *    element.
 *  - A BooleanParameter has a boolean value, and corresponds to the boolean UI
 *    element.
 *  - A PickerParameter has a value of indeterminate type selected from a list
 *    of possible values, and corresponds to the single-column picker UI
 *    element.
 */
enum ParameterType { StringParameter, BooleanParameter, PickerParameter };

/**
 *  The ID of the parameter. This must be one of the constants defined above.
 */
@property NSString *paramId;

/**
 *  The display name of the parameter.
 */
@property NSString *displayName;

/**
 *  The value of the parameter.
 */
@property NSString *value;

/**
 *  The type of the parameter.
 */
@property enum ParameterType type;

/**
 *  The index of the parameter's value. This property only applies when the
 *  parameter type is PickerParameter.
 */
@property int index;

/**
 *  The possible values of the parameter. This property only applies when the
 *  parameter type is PickerParameter.
 */
@property NSArray *possibleValues;

@end
