/** @example ex/ios/ParameterInterface.h
 */

/*
 *  Copyright 2014-2025 Solace Corporation. All rights reserved.
 */

#import "Parameter.h"

/**
 *  The ParameterInterface class allows examples and the user interface to
 *  create, access and manipulate parameters. Each example has its own
 *  ParameterInterface.
 */
@interface ParameterInterface : NSObject

/**
 *  Contains each parameter used by an example object.
 */
@property NSMutableArray *parameters;

/**
 *  Adds the parameter that corresponds to the specified ID.
 *
 *  @param paramId The parameter's ID.
 */
- (void)addParameter:(NSString *)paramId;

/**
 *  Removes the parameter that corresponds to the specified ID.
 *
 *  @param paramId The parameter's ID.
 *
 *  @return YES if the parameter was removed, NO if not.
 */
- (BOOL)removeParameter:(NSString *)paramId;

/**
 *  Checks to see if the parameter with the specified ID exists.
 *
 *  @param paramId The ID of the parameter.
 *
 *  @return A value indicating whether the parameter exists.
 */
- (BOOL)containsParameter:(NSString *)paramId;

/**
 *  Gets the parameter with the specified ID.
 *
 *  @param paramId The ID of the parameter.
 *
 *  @return The parameter with the specified ID, or null if it does not exist.
 */
- (Parameter *)parameterWithId:(NSString *)paramId;

/**
 *  Gets the parameter at the specified index.
 *
 *  @param index The index of the parameter.
 *
 *  @return The parameter at the specified index, or null if it does not exist.
 */
- (Parameter *)parameterAtIndex:(int)index;

/**
 *  Gets the number of parameters that have been added.
 *
 *  @return The number of parameters.
 */
- (int)numOfParameters;

@end
