/**
 *  LogViewController.h
 *
 *  Copyright 2014-2025 Solace Corporation. All rights reserved.
 */

#import <UIKit/UIKit.h>
#import "Example.h"

/**
 *  The LogViewController is the controller that the user sees upon entering
 *  parameter values in the ParameterViewController and pressing next. The
 *  controller consists of a log text view and a Run button. The user presses
 *  Run to start the example, and the text view is updated with the example's
 *  log entries.
 */
@interface LogViewController : UIViewController

/**
 *  The example associated with the log output.
 */
@property(weak, nonatomic) Example *example;

/**
 *  The navigation bar of the view.
 */
@property(weak, nonatomic) IBOutlet UINavigationItem *navigItem;

/**
 *  Button that, when pressed, starts the example.
 */
@property(weak, nonatomic) IBOutlet UIBarButtonItem *runButton;

/**
 *  Text view that displays log output from the example.
 */
@property(weak, nonatomic) IBOutlet UITextView *logTextView;

/**
 *  Called when the run button is pressed. Starts the example.
 *
 *  @param sender The source of the method call.
 */
- (IBAction)onRunPressed:(id)sender;

/**
 *  Adds text to the text view.
 *
 *  @param notification The notification containing the text to add to the text
 *                      view.
 */
- (void)updateTextViewWithNotification:(NSNotification *)notification;

/**
 *  Adds text to the text view.
 *
 *  @param str The text to add to the text view.
 */
- (void)updateTextViewWithString:(NSString *)str;

@end
