/**
 *  LogViewController.m
 *
 *  Copyright 2014-2025 Solace Corporation. All rights reserved.
 */

#import "LogViewController.h"
#import "ParameterViewController.h"
#import "Example.h"
#import "ParameterInterface.h"

@implementation LogViewController

@synthesize example;
@synthesize runButton;
@synthesize logTextView;
@synthesize navigItem;

- (id)initWithCoder:(NSCoder *)aDecoder {
    if (self = [super initWithCoder:aDecoder]) {
        // Accept log notifications from example
        [[NSNotificationCenter defaultCenter]
            addObserver:self
               selector:@selector(updateTextViewWithNotification:)
                   name:@"output"
                 object:nil];
    }
    return self;
}

- (void)viewDidLoad {
    [super viewDidLoad];

    // Reset log view
    logTextView.text = @"";

    // Monitor state of example
    [example addObserver:self forKeyPath:@"running" options:0 context:NULL];
}

- (IBAction)onRunPressed:(id)sender {
    if (!example.running) {
        // Change run button to cancel button and hide back button
        runButton.title = @"Cancel";
        navigItem.hidesBackButton = YES;
        example.requestRun = YES;
    } else {
        // Disable cancel button (only one request necessary)
        runButton.enabled = NO;
        [example cancel];
    }
}

- (void)updateTextViewWithNotification:(NSNotification *)notification {
    NSString *string = [[notification userInfo] objectForKey:@"string"];
    [self updateTextViewWithString:string];
}

- (void)updateTextViewWithString:(NSString *)string {
    // Log updates must happen on the UI thread
    [self performSelectorOnMainThread:@selector(updateTextView:)
                           withObject:string
                        waitUntilDone:NO];
}
- (void)updateTextView:(id)textToAdd {
    logTextView.text = [[logTextView text]
        stringByAppendingFormat:@"%@\n", (NSString *)textToAdd];
}

- (void)observeValueForKeyPath:(NSString *)keyPath
                      ofObject:(id)object
                        change:(NSDictionary *)change
                       context:(void *)context {
    // Reset run button and show back button when example stops running
    if ([keyPath isEqualToString:@"running"]) {
        if (!example.running) {
            dispatch_async(dispatch_get_main_queue(), ^{
                self.runButton.title = @"Run";
                self.navigItem.hidesBackButton = NO;
                self.runButton.enabled = YES;
            });
        }
    }
}

- (void)didMoveToParentViewController:(UIViewController *)parent {
    if (![parent isEqual:self.parentViewController]) {
        // Disable observation when controller is no longer in view
        [example removeObserver:self forKeyPath:@"running"];
    }
}

- (void)dealloc {
    [[NSNotificationCenter defaultCenter] removeObserver:self];
}

@end
