/**
 *  ParameterViewController.h
 *
 *  Copyright 2014-2025 Solace Corporation. All rights reserved.
 */

#import <Foundation/Foundation.h>
#import "Example.h"

/**
 *  The ParameterViewController is the view controller that the user sees upon
 *  pressing on an example in the RootViewController. It consists of a list of
 *  configuration parameters for that example.
 */
@interface ParameterViewController : UIViewController

/**
 *  Number of additional empty cells to add to table view to avoid having
 *  parameters stuck under the keyboard.
 */
#define PADDING_CELLS 6

/**
 *  The example associated with the parameters in the table view.
 */
@property(weak, nonatomic) Example *example;

/**
 *  A table view containing a list of parameters.
 */
@property(weak, nonatomic) IBOutlet UITableView *parameterTableView;

- (IBAction)switchValueChanged:(id)sender;

/**
 *  Creates a string cell (text box) for a table view.
 *
 *  @param tableView The table view for which the string cell is being created.
 *  @param parameter The parameter that corresponds to the new cell.
 *
 *  @return The new cell.
 */
- (UITableViewCell *)createStringCell:(UITableView *)tableView
                       parameterToAdd:(Parameter *)parameter;

/**
 *  Creates a boolean cell (switch) for a table view.
 *
 *  @param tableView The table view for which the cell is being created.
 *  @param parameter The parameter that corresponds to the new cell.
 *
 *  @return The new cell.
 */
- (UITableViewCell *)createBooleanCell:(UITableView *)tableView
                        parameterToAdd:(Parameter *)parameter;

/**
 *  Creates a picker cell for a table view.
 *
 *  @param tableView The table view for which the cell is being created.
 *  @param parameter The parameter that corresponds to the new cell.
 *
 *  @return The new cell.
 */
- (UITableViewCell *)createPickerCell:(UITableView *)tableView
                       parameterToAdd:(Parameter *)parameter;
@end