/**
 *  RootViewController.h
 *
 *  Copyright 2014-2025 Solace Corporation. All rights reserved.
 */

#import <UIKit/UIKit.h>
#import "ExampleInterface.h"

/**
 *  The RootViewController is the view controller that the user sees upon
 *  app startup. It consists of a list of examples. Each item in the list can
 *  be selected to open the configuration panel for that particular example.
 */
@interface RootViewController : UIViewController

/**
 *  An interface allowing access to all of the application's examples.
 */
@property(strong, nonatomic) ExampleInterface *exampleInterface;

/**
 *  A table view containing a list of examples.
 */
@property(weak, nonatomic) IBOutlet UITableView *exampleTableView;

/**
 *  A button that, when clicked, shows the about dialog.
 */
@property(weak, nonatomic) IBOutlet UIBarButtonItem *aboutButton;

/**
 *  Shows the about dialog.
 *
 *  @param sender The source of the method call.
 */
- (IBAction)showAboutDialog:(id)sender;

@end