/**
 *  RootViewController.h
 *
 *  Copyright 2014-2025 Solace Corporation. All rights reserved.
 */

#import "Example.h"
#import "ParameterViewController.h"
#import "RootViewController.h"

@implementation RootViewController

@synthesize exampleInterface;
@synthesize exampleTableView;
@synthesize aboutButton;

- (void)viewDidLoad {
    [super viewDidLoad];

    // Set up about button
    [self.aboutButton setTarget:self];
    [self.aboutButton setAction:@selector(showAboutDialog:)];
}

- (void)prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender {
    // Pass selected example to next view controller
    ParameterViewController *newController =
        (ParameterViewController *)segue.destinationViewController;
    Example *selectedExample = [exampleInterface
        example:(int)[self.exampleTableView indexPathForSelectedRow].row];
    newController.example = selectedExample;
}

- (IBAction)showAboutDialog:(id)sender {
    // The about dialog consists of a simple UIAlertView
    UIAlertView *statusAlert =
        [[UIAlertView alloc] initWithTitle:@"About"
                                   message:@"\nCCSMP iOS Examples\n\nCopyright 2014-2025 Solace Corporation. All rights reserved."
                                  delegate:nil
                         cancelButtonTitle:@"OK"
                         otherButtonTitles:nil];
    [statusAlert show];
}

- (ExampleInterface *)exampleInterface {
    if (!exampleInterface) {
        exampleInterface = [[ExampleInterface alloc] init];
    }

    return exampleInterface;
}

- (UITableViewCell *)tableView:(UITableView *)sourceTableView
         cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    // Generate table view cells based on the examples contained in the example
    // interface
    UITableViewCell *cell =
        [sourceTableView dequeueReusableCellWithIdentifier:@"sampleCell"];

    cell.textLabel.text = [exampleInterface exampleName:(int)indexPath.row];
    cell.detailTextLabel.text =
        [exampleInterface exampleDescription:(int)indexPath.row];

    return cell;
}

- (NSInteger)tableView:(UITableView *)tableView
    numberOfRowsInSection:(NSInteger)section {
    // The number of rows in the table view corresponds to the number of
    // examples
    return [self.exampleInterface numberOfExamples];
}

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView {
    // The table view only has one section
    return 1;
}

@end
