/** @example ex/ios/examples/AppReachabilityExample.h
 */
/*
 *  Copyright 2014-2025 Solace Corporation. All rights reserved.
 */

#import "Example.h"
#import "Reachability.h"

/**
 *  The AppReachabilityExample demonstrates how to respond to changes in network
 *  state using the Reachability API on iOS.
 */
@interface AppReachabilityExample : Example

/**
 *  Session pointer.
 */
@property solClient_opaqueSession_pt session_p;

/**
 *  Pointer to Reachability class.
 */
@property Reachability *reachability;

/**
 *  Current network status (WiFi active, WWAN active, or no connection).
 */
@property NetworkStatus currentNetworkStatus;

/**
 *  Indicates whether WiFi or WWAN is active but an Internet connection has not
 *  yet been established.
 */
@property BOOL currentConnectionRequired;

/**
 *  Indicates whether the CCSMP API has recently issued a reconnection event.
 */
@property BOOL receivedReconnectedEvent;

/**
 *  Indicates whether the thread is currently blocked.
 */
@property BOOL isThreadBlocked;

/**
 *  Called when the network status changes.
 *
 *  @param note Notification issued by the Reachability API.
 */
- (void)reachabilityChanged:(NSNotification *)note;

/**
 *  Blocks the current thread while there is no Internet connection.
 */
- (void)blockThreadDuringConnectionLoss;

/**
 *  Checks whether the last CCSMP API error was the result of connection loss.
 *
 *  @return A value indicating whether the last CCSMP API error was the result
 *          of connection loss.
 */
- (BOOL)isLastErrorConnectionLoss;

@end
