/** @example ex/ios/examples/EventMonitorExample.h
 */

/*
 *  Copyright 2009-2025 Solace Corporation. All rights reserved.
 */

#import "Example.h"

/**
 *  The EventMonitorExample demonstrates how to monitor appliance events using a
 *  relevant appliance event subscription.
 *
 *  Sample Requirements:
 *   - A Solace appliance running SolOS-TR.
 *   - The CLI configuration "Publish Client Event Messages" must be enabled
 *     in the client's Message VPN on the appliance.
 *
 *  This sample, a subscription is made to the appliance Event Topic for Client
 *  Connect
 *  events:
 *
 *        #LOG/INFO/CLIENT/<appliance hostname>/CLIENT_CLIENT_CONNECT/>
 *
 *  With "Publish Client Event Messages" enabled for the Message VPN,
 *  all client events are published as messages. By subscribing to the above
 *  Topic,
 *  all CLIENT_CLIENT_CONNECT event messages are received from the specified
 *  appliance.
 *
 *  Event message topics are treated as regular Topics in that wildcarding can
 *  be used in the same manner as typical Topics. For example, if you want to
 *  receive all client events, regardless of Event Level, the following Topic
 *  could be used:
 */

// #LOG/*/CLIENT/<appliance hostname>/>

/**
 *  This sample triggers a CLIENT_CLIENT_CONNECT event by connecting a second
 *  time to the router (triggerSecondaryConnection()).
 */
@interface EventMonitorExample : Example

/**
 *  Triggers a secondary connection in order to create an event message that
 *  this example will be able to log.
 *
 *  @param context_p The context associated with the secondary connection.
 *
 *  @return A return code relating to the secondary connection attempt.
 */
- (solClient_returnCode_t)triggerSecondaryConnectionWithContext:
        (solClient_opaqueContext_pt)context_p;

@end
