/** @example ex/ios/examples/SecureSessionExample.h
 */

/*
 *  Copyright 2009-2025 Solace Corporation. All rights reserved.
 */

#import "Example.h"

/**
 *  The SecureSessionExample demonstrates how to subscribe to a Topic for Direct
 *  messages, publish Direct messages to a Topic, receive messages through a
 *  callback function, explicitly configure session encryption properties, and
 *  connect a session to the appliance using SSL over TCP.
 *
 *  This sample shows the basics of creating a Context, creating a Secure
 *  Session, connecting a Session using SSL over TCP, subscribing to a Topic,
 *  and publishing Direct messages to a Topic. It uses a message callback that
 *  simply prints any received message to the screen.
 *
 *  A server certificate needs to be installed on the appliance and SSL must be
 *  enabled on the appliance for this sample to work.
 *
 *  Also, in order to connect to the appliance with Certificate Validation
 *  enabled (which is enabled by default), the appliance's certificate chain
 *  must be signed by one of the root CAs in the trust store used by the sample.
 *
 *  For this sample to use CLIENT CERTIFICATE authentication, a trust store has
 *  to be set up on the appliance and it must contain the root CA that signed
 *  the client certificate. The VPN must also have client-certificate
 *  authentication enabled.
 */
@interface SecureSessionExample : Example

/**
 *  SSL authentication schemes.
 */
typedef enum _authenticationScheme {
    _AUTHENTICATION_SCHEME_BASIC,
    _AUTHENTICATION_SCHEME_CLIENT_CERTIFICATE,
} _authenticationScheme_t;

@end
