/** @example ex/ios/examples/SempGetOverMbExample.h
 */

/*
 * Copyright 2009-2025 Solace Corporation. All rights reserved.
 */

#import "Example.h"

/**
 *  The SempGetOverMbExample demonstrates how to perform a Solace Element
 *  Management Protocol (SEMP) request over the Message Backbone.
 *
 *  Sample requirements:
 *   - A Solace appliance running SolOS-TR.
 *   - When running with SolOS-TR 5.3.1 and above. The client's Message VPN must
 *     have semp-over-msgbus enabled
 *   - The client's Message VPN must have the SEMP over Message Bus and Show
 *     Commands enabled.
 *
 *  This sample sends a SEMP request to show all clients currently connected to
 *  the appliance. The reply to the request is logged. This is a basic example
 *  of SEMP request/reply. Other similar requests could be used to create a
 *  customized appliance monitoring application.
 */
@interface SempGetOverMbExample : Example

/**
 *  Sends a blocking SEMP request to the appliance. The reply is logged
 *
 *  @param session_p   A pointer to the session on which to send the request.
 *  @param sempVersion The SEMP version to use.
 */
- (void)sempRequestRequestAndReplyWithSession:
            (solClient_opaqueSession_pt)session_p
                                  sempVersion:(const char *)sempVersion;

@end
