/** @example ex/ios/examples/TopicDispatchExample.h
 */

/*
 * Copyright 2007-2025 Solace Corporation. All rights reserved.
 */

#import "Example.h"

/**
 *  The TopicDispatchExample demonstrates using local topic dispatch to direct
 *  received messages into specialized received data paths.
 *
 *  This sample performs the following steps:
 *   - Adds subscription "a/>" to the appliance to receive all messages with a
 *     topic prefix of "a/"
 *   - Adds local dispatch function 1 for Topic "a/b"
 *   - Adds dispatch function 2 and subscription for "c/>"
 *   - Adds local dispatch function 3 for subscription "c/d"
 *   - Publishes on topic a/c and verifies receipt only on session callback
 *   - Publishes on topic a/b and verifies receipt only on dispatch function 1
 *   - Publishes on topic c/d and verifies receipt on both dispatch functions 2
 *     and 3
 *   - Publishes on topic c/e and verifies receipt on only dispatch function 2
 */
@interface TopicDispatchExample : Example

/**
 *  Array representing number of messages received for different topic
 *  dispatches.
 */
@property NSMutableArray *solMsgRxCount;

@end
